==> drawVlp7.4-2012-11-03.tgz: drawVlp7.4-2012-11-03/draw_3D_zm_log.rb <==
# -*- coding: iso-2022-jp -*-
require 'gphys_const_v1.1'
require 'gphys_methods_v1.4'
require "numru/ggraph"
include NumRu
include NMath

dir = ARGV[0]
vname = ARGV[1]
iyrs = ARGV[2].to_i
iyre = ARGV[3].to_i
imon = ARGV[4].to_i

title = MonNames[imon-1]


if vname == 'MSF'
  vnameinfile = 'V'
elsif vname == 'ANGMOM'
  vnameinfile = 'U'
else
  vnameinfile = vname
end
gphys = GPhys::IO.open( dir+'/'+vnameinfile+'.nc', vnameinfile )


#gphyszm = dcpam_clim_mon_mean( iyrs, iyre, imon, gphys )
gphyszm = gphys.mean('time')
gphyszm = gphyszm.mean('lon')
if vname == 'MSF'
  gphyszm = calc_msf( gphyszm )
elsif vname == 'ANGMOM'
  gphyszm = calc_angmom( gphyszm )
elsif vname == 'DustDensScledOptDep'
  gphyszm = gphyszm / 2.0
  gphyszm = gphyszm * 1e4
  gphyszm.long_name = "dust density-scaled optical depth at infrared"
  gphyszm.units = "1e-4 m2 kg-1"
end
rmiss = gphys.get_att('missing_value')[0]

# $B%l%Y%k!u%Q%?!<%s$rM[$K;XDj(B
# $B%Q%?%s$NJ}$,(B1$B$DB?"*!^!g$^$G(B
if vname == 'Temp'
# Earth
  levels = [170,180,190,200,210,220,230,240,250,260,270,280,290,300]
# Mars
  levels = [110,120,130,140,150,160,170,180,190,200,210,220,230,240]
  patterns = [10999,15999,20999,25999,30999,35999,40999,50999,60999,65999,70999,75999,80999,90999,95999]
# Venus
  levels = [100,150,200,250,300,350,400,450,500,550,600,650,700,750]
  patterns = [10999,15999,20999,25999,30999,35999,40999,50999,60999,65999,70999,75999,80999,90999,95999]
elsif vname == 'U'
# Earth
  levels = [-20,-15,-10,-5,0,5,10,15,20,25,30,35,40,45,50]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,90999]
# Mars
  levels = [-160,-140,-120,-100,-80,-60,-40,-20,0,20,40,60,80,100,120,140,160]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999,95999]
elsif vname == 'MSF'
# Earth
  levels = [-20e2,-17.5e2,-15e2,-12.5e2,-10e2,-7.5e2,-5e2,-2.5e2,0,2.5e2,5e2,7.5e2,10e2,12.5e2,15e2,17.5e2,20e2]
# Mars
  levels = [-20e0,-17.5e0,-15e0,-12.5e0,-10e0,-7.5e0,-5e0,-2.5e0,0,2.5e0,5e0,7.5e0,10e0,12.5e0,15e0,17.5e0,20e0]
  levels = [-40e0,-35e0,-30e0,-25e0,-20e0,-15e0,-10e0,-5e0,0,5e0,10e0,15e0,20e0,25e0,30e0,35e0,40e0]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999,95999]
  levels = [-100e0,-90e0,-80e0,-70e0,-60e0,-50e0,-40e0,-30e0,-20e0,-10e0,0,10e0,20e0,30e0,40e0,50e0,60e0,70e0,80e0,90e0,100e0]
  patterns = [10999,15999,20999,25999,30999,32999,35999,40999,42999,45999,50999,55999,60999,65999,70999,75999,80999,82999,85999,90999,92999,95999]
# Venus
  levels = [-1e5,-3e4,-1e4,-3e3,-1e3,-3e2,-1e2,-3e1,-1e1,-3e0,0,3e0,1e1,3e1,1e2,3e2,1e3,3e3,1e4,3e4,1e5]
  patterns = [10999,15999,20999,25999,30999,32999,35999,40999,42999,45999,50999,55999,60999,65999,70999,75999,80999,82999,85999,90999,92999,95999]
elsif vname == 'ANGMOM'
# Earth
  levels = [0,2,4,6,8,10,12,14,16,18,20,22,24,26,28,30]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999]
# Mars
  levels = [0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999]
elsif vname == 'QVap'
  levels = [1e-4,2e-3,4e-3,6e-3,8e-3,10e-3,12e-3,14e-3,16e-3,18e-3,20e-3]
  patterns = [1,10999,20999,30999,40999,50999,60999,65999,70999,80999,90999,95999]
elsif vname == 'DustDensScledOptDep'
  levels = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999,95999]
end

# Color map is changed for mass stream function.
if vname == 'U'
#  DCL.sgscmn(4)  # blue-cyan-white-yellow-red
  DCL.sgscmn(14) # blue-white-red
elsif vname == 'MSF'
  DCL.sgscmn(14) # blue-white-red
end


DCL.gropn(2)
#DCL.sldiv('y',2,2)           # 2x2$B$K2hLLJ,3d(B, 'y'=yoko: $B:8>e"*1&>e"*:82<(B...
DCL.sgpset('lcntl', false)   # $B@)8fJ8;z$r2r<a$7$J$$(B
DCL.sgpset('lfull',true)     # $BA42hLLI=<((B
DCL.uzfact(0.7)             # $B:BI8<4$NJ8;zNs%5%$%:$r(B 0.75 $BG\(B
DCL.sgpset('lfprop',true)    # $B%W%m%]!<%7%g%J%k%U%)%s%H$r;H$&(B

DCL.glpset('lmiss',true)
DCL.glpset('rmiss',rmiss)

#< GGraph $B$K$h$k(B $BIA2h(B >
# Earth
#GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,1e5,1e3]
# Mars
#GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,1e3,1e-1]
#GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,1e3,1e-2]
GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,91e5,1e1]
GGraph.set_axes('xlabelint'=>30)

GGraph.tone( gphyszm, true, 'lev'=>levels, 'pat'=>patterns, 'annotate'=>false )
#if vname == 'V' || vname =='U'
#  GGraph.contour( gphyszm, false, 'lev'=>[0], 'index'=>3, 'annotate'=>false )
#end
GGraph.contour( gphyszm, false, 'lev'=>levels, 'index'=>3, 'annotate'=>false )
GGraph.color_bar

#DCL::uxmttl('T', ' ', 1.0)
#DCL::uxmttl('T', title, -1.0)

DCL.grcls

==> drawVlp7.5-2015-02-16.tgz: drawVlp7.5-2015-02-16/draw_3D_zm_log.rb <==
require './gphys_const_v1.1'
require './gphys_methods_v1.4'
require "numru/ggraph"
require 'numru/gphys/ep_flux'
require 'numru/ggraph_on_merdional_section'
include NumRu
include NMath

dir = ARGV[0]
vname = ARGV[1]
iyrs = ARGV[2].to_i
iyre = ARGV[3].to_i
imon = ARGV[4].to_i

title = MonNames[imon-1]


if vname == 'MSF'
  vnameinfile = 'V'
elsif vname == 'ANGMOM'
  vnameinfile = 'U'
else
  vnameinfile = vname
end
gphys = GPhys::IO.open( dir+'/'+vnameinfile+'.nc', vnameinfile )


#gphyszm = dcpam_clim_mon_mean( iyrs, iyre, imon, gphys )
if vname == 'epflx_div'
  gphyszm = gphys.mean('time')
  gpepy = GPhys::IO.open( dir+'/'+'epflx_y'+'.nc', 'epflx_y' ).mean('time')
  gpepz = GPhys::IO.open( dir+'/'+'epflx_z'+'.nc', 'epflx_z' ).mean('time')
else
  gphyszm = gphys.mean('time')
  gphyszm = gphyszm.mean('lon')
end

if vname == 'MSF'
  gphyszm = calc_msf( gphyszm )
elsif vname == 'ANGMOM'
  gphyszm = calc_angmom( gphyszm )
elsif vname == 'DustDensScledOptDep'
  gphyszm = gphyszm / 2.0
  gphyszm = gphyszm * 1e4
  gphyszm.long_name = "dust density-scaled optical depth at infrared"
  gphyszm.units = "1e-4 m2 kg-1"
end
rmiss = gphys.get_att('missing_value')[0]

# $B%l%Y%k!u%Q%?!<%s$rM[$K;XDj(B
# $B%Q%?%s$NJ}$,(B1$B$DB?"*!^!g$^$G(B
# 55 $B$,Gr?'(B
if vname == 'Temp'
# Earth
  levels = [170,180,190,200,210,220,230,240,250,260,270,280,290,300]
# Mars
  levels = [110,120,130,140,150,160,170,180,190,200,210,220,230,240]
  patterns = [10999,15999,20999,25999,30999,35999,40999,50999,60999,65999,70999,75999,80999,90999,95999]
# Venus
  levels = [100,150,200,250,300,350,400,450,500,550,600,650,700,750]
  patterns = [10999,15999,20999,25999,30999,35999,40999,50999,60999,65999,70999,75999,80999,90999,95999]
elsif vname == 'U'
# Earth
  levels = [-20,-15,-10,-5,0,5,10,15,20,25,30,35,40,45,50]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,90999]
# Mars
  levels = [-160,-140,-120,-100,-80,-60,-40,-20,0,20,40,60,80,100,120,140,160]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999,95999]
elsif vname == 'V'
# Venus
  levels = [-7,-6,-5,-4,-3,-2,-1,0,1,2,3,4,5,6,7]
  patterns = [15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999]
elsif vname == 'OMG'
# Venus
#  levels = [-1.25,-1,-0.75,-0.50,-0.25,0,0.25,0.50,0.75,1,1.25,1.50,1.75,2,2.25,2.50]
  levels = [-1,-1e-1,-1e-2,-1e-3,-1e-4,0,1e-4,1e-3,1e-2,1e-1,1]
#  patterns = [38999,41999,44999,47999,49999,52999,55999,58999,61999,64999,67999,70999,73999,76999,79999,82999,85999]
  patterns = [38999,41999,44999,47999,49999,52999,55999,58999,61999,64999,67999,70999]
elsif vname == 'epflx_div'
# Venus
#  levels = [-2.5e-7,-2e-7,-1.5e-7,-1e-7,-0.5e-7,0,0.5e-7,1e-7,1.5e-7,2.0e-7,2.5e-7]
#  levels = [-1e-5,-5e-6,-1e-6,-5e-7,-1e-7,0,1e-7,5e-7,1e-6,5e-6,1e-5]
#  levels = [-1e-5,-3e-6,-1e-6,-3e-7,-1e-7,0,1e-7,3e-7,1e-6,3e-6,1e-5]
  levels = [-4.5e-5,-2e-5,-1e-5,-4.5e-6,-2e-6,-1e-6,0,1e-6,2e-6,4.5e-6,1e-5,2e-5,4.5e-5]
#  patterns = [25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999]
  patterns = [20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999]
elsif vname == 'MSF'
# Earth
  levels = [-20e2,-17.5e2,-15e2,-12.5e2,-10e2,-7.5e2,-5e2,-2.5e2,0,2.5e2,5e2,7.5e2,10e2,12.5e2,15e2,17.5e2,20e2]
# Mars
  levels = [-20e0,-17.5e0,-15e0,-12.5e0,-10e0,-7.5e0,-5e0,-2.5e0,0,2.5e0,5e0,7.5e0,10e0,12.5e0,15e0,17.5e0,20e0]
  levels = [-40e0,-35e0,-30e0,-25e0,-20e0,-15e0,-10e0,-5e0,0,5e0,10e0,15e0,20e0,25e0,30e0,35e0,40e0]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999,95999]
  levels = [-100e0,-90e0,-80e0,-70e0,-60e0,-50e0,-40e0,-30e0,-20e0,-10e0,0,10e0,20e0,30e0,40e0,50e0,60e0,70e0,80e0,90e0,100e0]
  patterns = [10999,15999,20999,25999,30999,32999,35999,40999,42999,45999,50999,55999,60999,65999,70999,75999,80999,82999,85999,90999,92999,95999]
# Venus
  levels = [-1e5,-3e4,-1e4,-3e3,-1e3,-3e2,-1e2,-3e1,-1e1,-3e0,0,3e0,1e1,3e1,1e2,3e2,1e3,3e3,1e4,3e4,1e5]
  patterns = [10999,15999,20999,25999,30999,32999,35999,40999,42999,45999,50999,55999,60999,65999,70999,75999,80999,82999,85999,90999,92999,95999]
elsif vname == 'ANGMOM'
# Earth
  levels = [0,2,4,6,8,10,12,14,16,18,20,22,24,26,28,30]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999]
# Mars
  levels = [0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999]
elsif vname == 'QVap'
  levels = [1e-4,2e-3,4e-3,6e-3,8e-3,10e-3,12e-3,14e-3,16e-3,18e-3,20e-3]
  patterns = [1,10999,20999,30999,40999,50999,60999,65999,70999,80999,90999,95999]
elsif vname == 'DustDensScledOptDep'
  levels = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17]
  patterns = [10999,15999,20999,25999,30999,35999,40999,45999,50999,55999,60999,65999,70999,75999,80999,85999,90999,95999]
end

# Color map is changed for mass stream function.
if vname == 'U'
#  DCL.sgscmn(4)  # blue-cyan-white-yellow-red
  DCL.sgscmn(14) # blue-white-red
elsif vname == 'V'
  DCL.sgscmn(14) # blue-white-red
elsif vname == 'OMG'
  DCL.sgscmn(14) # blue-white-red
elsif vname == 'MSF'
  DCL.sgscmn(14) # blue-white-red
elsif vname == 'epflx_div'
  DCL.sgscmn(14) # blue-white-red
end


DCL.gropn(2)
#DCL.sldiv('y',2,2)           # 2x2$B$K2hLLJ,3d(B, 'y'=yoko: $B:8>e"*1&>e"*:82<(B...
DCL.sgpset('lcntl', false)   # $B@)8fJ8;z$r2r<a$7$J$$(B
DCL.sgpset('lfull',true)     # $BA42hLLI=<((B
DCL.uzfact(0.7)             # $B:BI8<4$NJ8;zNs%5%$%:$r(B 0.75 $BG\(B
DCL.sgpset('lfprop',true)    # $B%W%m%]!<%7%g%J%k%U%)%s%H$r;H$&(B

DCL.glpset('lmiss',true)
DCL.glpset('rmiss',rmiss)

#< GGraph $B$K$h$k(B $BIA2h(B >
# Earth
#GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,1e5,1e3]
# Mars
#GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,1e3,1e-1]
#GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,1e3,1e-2]
GGraph.set_fig 'itr'=>2, 'viewport'=>[0.15,0.85,0.15,0.6], 'yrev'=>'units:Pa', 'window'=>[-90,90,91e5,1e1]
GGraph.set_axes('xlabelint'=>30)

GGraph.tone( gphyszm, true, 'lev'=>levels, 'pat'=>patterns, 'annotate'=>false )
#if vname == 'V' || vname =='U'
#  GGraph.contour( gphyszm, false, 'lev'=>[0], 'index'=>3, 'annotate'=>false )
#end
GGraph.contour( gphyszm, false, 'lev'=>levels, 'index'=>3, 'annotate'=>false )

#if vname == 'epflx_div'
#	GGraph::vector_on_merdional_section(gpepy, gpepz, false,
#	    'fact'=>3.0,'xintv'=>1,'unit'=>true,'annot'=>false
#	                                    )
#end

#if vname == 'OMG'
#	GGraph.color_bar( 'log'=>true )
#else
	GGraph.color_bar
#end

#DCL::uxmttl('T', ' ', 1.0)
#DCL::uxmttl('T', title, -1.0)

DCL.grcls
